@@ -35,7 +35,7 @@ under the same terms as Perl itself.
 
 =cut
 
-our $VERSION = '0.029'; # VERSION
+our $VERSION = '0.030'; # VERSION
 
 use Mouse;
 
@@ -334,7 +334,7 @@ sub get_cvprop_values
 
   my $cv = $self->get_cv_by_name($cv_name);
   my $cvprops = $self->cvprop_data()->{$cv->{cv_id}};
-  my $prop_type = $self->get_cvterm_by_name($cv_name, $prop_type_name);
+  my $prop_type = $self->get_cvterm_by_name('cv_property_type', $prop_type_name);
 
   return map {
     $_->{value}
