@@ -33,7 +33,7 @@ under the same terms as Perl itself.
 
 =cut
 
-our $VERSION = '0.029'; # VERSION
+our $VERSION = '0.030'; # VERSION
 
 use warnings;
 use Carp;
@@ -59,6 +59,11 @@ our %field_conf = (
         my $dbxrefs = $2 // '';
 
         my @dbxrefs =
+          map {
+            # remove quoting
+            s|\\(.)|$1|g;
+            $_;
+          }
           grep {
             !m|^(?:url:)?https?\\?:| && /^\S+:\S+$/;
           } split /\s*,\s/, $dbxrefs;
